<?php

declare(strict_types=1);

/**
 * This file is part of the EaseHtml package
 *
 * https://github.com/VitexSoftware/php-ease-html
 *
 * (c) Vítězslav Dvořák <http://vitexsoftware.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Test\Ease\Html;

/**
 * Generated by PHPUnit_SkeletonGenerator on 2016-01-17 at 23:58:49.
 */
class SelectTagTest extends PairTagTest
{
    public string $rendered = '<select name="test"><option value="a">A</option><option value="b">B</option></select>';
    protected $object;

    /**
     * Sets up the fixture, for example, opens a network connection.
     * This method is called before a test is executed.
     */
    protected function setUp(): void
    {
        $this->object = new \Ease\Html\SelectTag(
            'test',
            ['a' => 'A', 'b' => 'B'],
        );
    }

    /**
     * Tears down the fixture, for example, closes a network connection.
     * This method is called after a test is executed.
     */
    protected function tearDown(): void
    {
    }

    /**
     * @covers \Ease\Html\SelectTag::addItems
     */
    public function testAddItems(): void
    {
        $this->object->addItems(['a' => 'b', 'c' => 'd']);
        $this->assertEquals(
            '<select name="test"><option value="a">A</option><option value="b">B</option><option value="a">b</option><option value="c">d</option></select>',
            $this->object->getRendered(),
        );
    }

    /**
     * @covers \Ease\Html\SelectTag::loadItems
     */
    public function testLoadItems(): void
    {
        $this->assertEquals([], $this->object->loadItems());
    }

    /**
     * @covers \Ease\Html\SelectTag::setValue
     */
    public function testSetValue(): void
    {
        $this->object->setValue('b');
        $this->assertEquals(
            '<select name="test"><option value="a">A</option><option value="b" selected>B</option></select>',
            $this->object->getRendered(),
        );
    }

    /**
     * @covers \Ease\Html\SelectTag::finalize
     */
    public function testFinalize(): void
    {
        $this->object->emptyContents();
        $this->object->finalize();
        $this->assertEquals(
            '<select name="test"></select>',
            $this->object->getRendered(),
        );
    }

    /**
     * @covers \Ease\Html\SelectTag::getTagName
     */
    public function testGetTagName(): void
    {
        $this->assertEquals('test', $this->object->getTagName());
    }

    /**
     * @covers \Ease\Html\SelectTag::delItem
     */
    public function testDelItem(): void
    {
        $this->object->delItem('a');
        $this->assertEquals(
            '<select name="test"><option value="b">B</option></select>',
            $this->object->getRendered(),
        );
    }

    /**
     * @covers \Ease\Container::addAsFirst
     */
    public function testAddAsFirst(): void
    {
        $this->object->emptyContents();

        $this->object->addAsFirst(new \Ease\Html\OptionTag('test', 'x'));

        $this->assertEquals(
            '<option value="x">test</option>',
            (string) current($this->object->getContents()),
        );
    }
}
